#include <iostream>
#include <cstdlib>
#include <string>
#include <stdint.h>

enum resource_t {
    TOOL,
    ELECTRONIC,
    PLASTIC,
    FOOD,
    RESOURCES_NUM
};

enum prodType_t {
    PROD_GARBAGE,
    PROD_PLANT,
    PROD_ELECTRONIC,
    PROD_PLASTIC,
    PROD_TYPES_NUM
};

enum prodState_t {
    NA,
    BUILDING,
    WORKING
};

struct prod_t {
    int32_t finishDay;
    int32_t takeDay;
    int32_t prodDay;
    prodState_t state;
};

int32_t resources[RESOURCES_NUM] = {40, 40, 40, 40};
int32_t takes[PROD_TYPES_NUM][RESOURCES_NUM] = {
    { 1, 0, 0, 0 },
    { 0, 0, 2, 0 },
    { 2, 0, 0, 0 },
    { 1, 1, 0, 0 }
};
int32_t produces[PROD_TYPES_NUM][RESOURCES_NUM] = {
    { 2, 0, 1, 0 },
    { 0, 0, 0, 8 },
    { 0, 6, 0, 0 },
    { 0, 0, 7, 0 }
};
int32_t buildTimes[PROD_TYPES_NUM] = {
    6, 4, 10, 8
};
int32_t productionTimes[PROD_TYPES_NUM] = {
    2, 6, 10, 7
};
int32_t takeTimes[PROD_TYPES_NUM] = {
    5, 10, 20, 12
};
int32_t buildResources[PROD_TYPES_NUM][RESOURCES_NUM] = {
    { 5, 5, 5, 0 },
    { 5, 0, 10, 0 },
    { 10, 5, 10, 0 },
    { 10, 5, 8, 0 }
};
prod_t prods[PROD_TYPES_NUM][5];
int32_t builds[PROD_TYPES_NUM][5];

int32_t day = 1;

void checkResources() {
    bool shouldBreak = false;

    for(uint32_t j = 0; j < RESOURCES_NUM; j++) {
        if(resources[j] <= 0) {
            shouldBreak = true;
            break;
        }
    }

    if(shouldBreak) {
        std::cout << day << "\n";

        for(uint32_t j = 0; j < RESOURCES_NUM; j++) {
            std::cout << resources[j] << "\n";
        }

        std::exit(0);
    }
}

int main() {
    int64_t x, y;
    std::cin >> x >> y;

    for(uint32_t i = 0; i < 4; i++) {
        for(uint32_t j = 0; j < 5; j++) {
            std::cin >> builds[i][j];
        }
    }

    for(; day <= 100; day++) {
        if((day % 10) == 0) {
            for(uint32_t j = 0; j < RESOURCES_NUM; j++)
                resources[j] += x;
        }

        for(uint32_t j = 0; j < RESOURCES_NUM; j++) {
            resources[j] -= y;
        }

        for(uint32_t i = 0; i < PROD_TYPES_NUM; i++) {
            bool can = true;

            for(uint32_t j = 0; j < 5; j++) {
                prod_t &prod = prods[i][j];

                if(prod.state == BUILDING && prod.finishDay <= day) {
                    can = false;
                    break;
                }
            }

            if(!can) {
                continue;
            }

            for(uint32_t j = 0; j < 5; j++) {
                prod_t &prod = prods[i][j];

                if(day >= builds[i][j] && builds[i][j]) {
                    builds[i][j] = 0;
                    prod.state = BUILDING;
                    prod.finishDay = day + buildTimes[i] - 1;

                    for(uint32_t k = 0; k < RESOURCES_NUM; k++) {
                        resources[k] -= buildResources[i][k];
                    }
                    break;
                }
            }
        }

        for(uint32_t i = 0; i < PROD_TYPES_NUM; i++) {
            for(uint32_t j = 0; j < 5; j++) {
                prod_t& prod = prods[i][j];

                switch(prod.state) {
                    case NA: {
                        break;
                    }

                    case BUILDING: {
                        if(day == prod.finishDay) {
                            prod.state = WORKING;
                            prod.takeDay = day + takeTimes[i];
                            prod.prodDay = day + productionTimes[i];
                        }
                        break;
                    }

                    case WORKING: {
                        if(day == prod.takeDay) {
                            for(uint32_t k = 0; k < RESOURCES_NUM; k++) {
                                resources[k] -= takes[i][k];
                            }

                            prod.takeDay += takeTimes[i];
                        }

                        if(day == prod.prodDay) {
                            for(uint32_t k = 0; k < RESOURCES_NUM; k++) {
                                resources[k] += produces[i][k];
                            }

                            prod.prodDay += productionTimes[i];
                        }

                        break;
                    }
                }
            }
        }

        checkResources();
    }

    day = std::min(100, day);

    std::cout << day << "\n";

    for(uint32_t j = 0; j < RESOURCES_NUM; j++) {
        std::cout << resources[j] << "\n";
    }

    return 0;
}
